local Otis = LibStub("AceAddon-3.0"):NewAddon("Otis", "AceEvent-3.0")

local function GetEncounters(t,k)
	local info = { ByIndex = {}, ByID = {} }

	index = 1
	local name, _, encounterID = EJ_GetEncounterInfoByIndex(index)
	while encounterID do
		-- print(index, name, encounterID)
		info.ByIndex[index] = encounterID
		info.ByID[encounterID] = index

		index = index + 1
		name, _, encounterID = EJ_GetEncounterInfoByIndex(index)
	end
	rawset(t, k, info)
	return info
end

local tblInstances = setmetatable( {}, { __index = GetEncounters } )

local strIconUp = "Interface\\ChatFrame\\UI-ChatIcon-ScrollUp-Up"
local strIconDown = "Interface\\ChatFrame\\UI-ChatIcon-ScrollDown-Up"
local btnUp, btnDown
	

function Otis.Up()
	if EncounterJournal then
		local instanceID, encounterID = EncounterJournal.instanceID, EncounterJournal.encounterID
		if instanceID and encounterID then
			local info = tblInstances[instanceID]
			local index = info.ByID[encounterID]
			if index > 1 then
				EncounterJournal_DisplayEncounter(info.ByIndex[index-1], true)
			elseif index == 1 then
				EncounterJournal_DisplayInstance(instanceID, true)
			end
		end
	end
end

function Otis.Down()
	if EncounterJournal then
		local instanceID, encounterID = EncounterJournal.instanceID, EncounterJournal.encounterID
		if instanceID then
			local info = tblInstances[instanceID]
			if encounterID then
				local index = info.ByID[encounterID]
				if index < #info.ByIndex then
					EncounterJournal_DisplayEncounter(info.ByIndex[index+1], true)
				end
			elseif #info.ByIndex > 0 then
				EncounterJournal_DisplayEncounter(info.ByIndex[1], true)
			end
		end
	end
end

function Otis:MakeButtons()
	if (type(EncounterJournalEncounterFrameInfoLootTab) ~= "table") then
		-- print("parent frame doesn't exist yet")
		return
	end

	-- print("making buttons")
	self:UnregisterEvent("EJ_LOOT_DATA_RECIEVED")
	self:UnregisterEvent("EJ_DIFFICULTY_UPDATE")

	btnUp = CreateFrame("Button", "OtisButton-Up", EncounterJournalEncounterFrameInfoLootTab)
	btnUp:SetPoint("TOP", EncounterJournalEncounterFrameInfoLootTab, "BOTTOM", 6, 2)
	btnUp:SetSize(63, 57)
	btnUp:SetNormalTexture(strIconUp)
	btnUp:SetScript("OnClick", Otis.Up)

	btnDown = CreateFrame("Button", "OtisButton-Down", EncounterJournalEncounterFrameInfoLootTab)
	btnDown:SetPoint("TOP", btnUp, "BOTTOM", 0, 2)
	btnDown:SetSize(63, 57)
	btnDown:SetNormalTexture(strIconDown)
	btnDown:SetScript("OnClick", Otis.Down)
end


-- Called when the addon is enabled
function Otis:OnEnable()
	self:RegisterEvent("EJ_LOOT_DATA_RECIEVED", "MakeButtons")
	self:RegisterEvent("EJ_DIFFICULTY_UPDATE",  "MakeButtons")
end

-- Called when the addon is disabled
function Otis:OnDisable()
	self:UnregisterEvent("EJ_LOOT_DATA_RECIEVED")
	self:UnregisterEvent("EJ_DIFFICULTY_UPDATE ")
end
